==> haskell-hls-call-hierarchy-plugin-2.1.0.0-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-call-hierarchy-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-call-hierarchy-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-call-hierarchy-plugin-2.1.0.0-H9judaxSTN9A7kkjZWzkcG
key:                  hls-call-hierarchy-plugin-2.1.0.0-H9judaxSTN9A7kkjZWzkcG
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Call hierarchy plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-call-hierarchy-plugin#readme>

category:             Development
abi:                  d4b1db7d7fecb25bcbbb2a9008366288
exposed:              True
exposed-modules:      Ide.Plugin.CallHierarchy
hidden-modules:
    Ide.Plugin.CallHierarchy.Internal Ide.Plugin.CallHierarchy.Query
    Ide.Plugin.CallHierarchy.Types

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-call-hierarchy-plugin
hs-libraries:         HShls-call-hierarchy-plugin-2.1.0.0-H9judaxSTN9A7kkjZWzkcG
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1 containers-0.6.7
    extra-1.7.16-KxrHBQWVwMp2M62XitBte8
    ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hiedb-0.4.3.0-77h4cPeELCh59Sg9LsTnNF
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    lsp-2.1.0.0-GxokUjVxBLy4j05JlhgdFg
    sqlite-simple-0.4.19.0-7u0AghWadLu8LxwMGeIVws text-2.0.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:
    /usr/share/doc/haskell-hls-call-hierarchy-plugin/html/hls-call-hierarchy-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-call-hierarchy-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-call-hierarchy-plugin-2.1.0.0-94-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-call-hierarchy-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-call-hierarchy-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-call-hierarchy-plugin-2.1.0.0-4pYMr2Jok3EICHjTaLKJlN
key:                  hls-call-hierarchy-plugin-2.1.0.0-4pYMr2Jok3EICHjTaLKJlN
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Call hierarchy plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-call-hierarchy-plugin#readme>

category:             Development
abi:                  9b2fdd2ffc1c75e0859544cd842c1068
exposed:              True
exposed-modules:      Ide.Plugin.CallHierarchy
hidden-modules:
    Ide.Plugin.CallHierarchy.Internal Ide.Plugin.CallHierarchy.Query
    Ide.Plugin.CallHierarchy.Types

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-call-hierarchy-plugin
hs-libraries:         HShls-call-hierarchy-plugin-2.1.0.0-4pYMr2Jok3EICHjTaLKJlN
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1 containers-0.6.7
    extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E
    ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hiedb-0.4.3.0-HW3gq1S374kGrDfXQW41UV
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    lsp-2.1.0.0-4wEItkatDyfAFCzTPH6SAN
    sqlite-simple-0.4.19.0-LE0uG2byo4o8ltMLMAEHAX text-2.0.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:
    /usr/share/doc/haskell-hls-call-hierarchy-plugin/html/hls-call-hierarchy-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-call-hierarchy-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
